@@ -6,7 +6,7 @@ Mojolicious::Plugin::LinkEmbedder - Convert a URL to embedded content
 
 =head1 VERSION
 
-0.18
+0.19
 
 =head1 DESCRIPTION
 
@@ -129,6 +129,8 @@ Caching is EXPERIMENTAL and could be removed without notice.
 
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter>
 
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis>
+
 =back
 
 =cut
@@ -140,7 +142,7 @@ use Mojo::UserAgent;
 use Mojolicious::Plugin::LinkEmbedder::Link;
 use constant DEBUG => $ENV{MOJO_LINKEMBEDDER_DEBUG} || 0;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 has _ua => sub { Mojo::UserAgent->new(max_redirects => 3) };
 
@@ -260,6 +262,7 @@ sub register {
     'ted'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted',
     'text'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text',
     'twitter'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter',
+    'travis-ci'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis',
     'video'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Video',
     'vimeo'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo',
     'youtube'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube',
