@@ -11,6 +11,7 @@ This class inherits from L<Mojolicious::Plugin::LinkEmbedder::Link::Text>.
 =cut
 
 use Mojo::Base 'Mojolicious::Plugin::LinkEmbedder::Link::Text';
+use Mojo::Util 'xml_escape';
 use Mojo::URL;
 
 =head1 ATTRIBUTES
@@ -49,10 +50,6 @@ has title       => '';
 has type        => '';
 has video       => '';
 
-sub _cache_attributes {
-  shift->SUPER::_cache_attributes, qw( canon_url description image title type video );
-}
-
 =head1 METHODS
 
 =head2 learn
@@ -66,7 +63,7 @@ sub learn {
     $self->url,
     sub {
       my ($ua, $tx) = @_;
-      my $dom = $tx->res->dom;
+      my $dom = $tx->success ? $tx->res->dom : undef;
       $self->_tx($tx)->_learn_from_dom($dom) if $dom;
       $self->$cb;
     },
@@ -82,14 +79,15 @@ Returns data about the HTML page in a div tag.
 =cut
 
 sub to_embed {
-  my $self = shift;
+  my $self  = shift;
+  my $title = xml_escape $self->title;
 
   if ($self->image) {
     return <<"EMBED";
 <div class="link-embedder text-html">
-  <div class="link-embedder-media"><img src="@{[$self->image]}" alt="@{[$self->title]}"></div>
-  <h3>@{[$self->title]}</h3>
-  <p>@{[$self->description]}</p>
+  <div class="link-embedder-media"><img src="@{[xml_escape $self->image]}" alt="$title"></div>
+  <h3>$title</h3>
+  <p>@{[xml_escape $self->description]}</p>
   <div class="link-embedder-link"><a href="@{[$self->canon_url]}" title="@{[$self->canon_url]}">@{[$self->canon_url]}</a></div>
 </div>
 EMBED
