@@ -18,6 +18,8 @@ use Mojo::Base 'Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML';
 
 Returns the the digit from the url L</url>.
 
+=head2 provider_name
+
 =cut
 
 has media_id => sub {
@@ -28,6 +30,8 @@ has media_id => sub {
   $media_id;
 };
 
+sub provider_name {'Vimeo'}
+
 =head1 METHODS
 
 =head2 learn
